aboutsummaryrefslogtreecommitdiff
path: root/gdb/hppah-nat.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/hppah-nat.c')
-rw-r--r--gdb/hppah-nat.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/gdb/hppah-nat.c b/gdb/hppah-nat.c
index aadaf9d..6b37166 100644
--- a/gdb/hppah-nat.c
+++ b/gdb/hppah-nat.c
@@ -200,12 +200,13 @@ fetch_register (regno)
error_exit:;
}
/* Resume execution of the inferior process.
If STEP is nonzero, single-step it.
If SIGNAL is nonzero, give it that signal. */
void
-child_resume (step, signal)
+child_resume (pid, step, signal)
+ int pid;
int step;
int signal;
{
@@ -200,12 +200,13 @@ fetch_register (regno)
error_exit:;
}
-/* Resume execution of the inferior process.
+/* Resume execution of process PID.
If STEP is nonzero, single-step it.
If SIGNAL is nonzero, give it that signal. */